import pathlib

import seisbench.models as sbm

from .model_runner import ModelRunner


class PhaseNetModelRunner(ModelRunner):

    model_type = "PhaseNet"

    def __init__(self, weights_name="original", output_dir=pathlib.Path("."), **kwargs):
        self.model_name = getattr(sbm, PhaseNetModelRunner.model_type)
        super(PhaseNetModelRunner, self).__init__(
            weights_name=weights_name, output_dir=output_dir, **kwargs
        )

    def process_kwargs(self, **kwargs):
        self.threshold_p = float(kwargs.get("threshold_p", 0.3))
        self.threshold_s = float(kwargs.get("threshold_s", 0.3))
        self.blinding = kwargs.get("blinding", (0, 0))

        self.annotate_kwargs = {}

        self.classify_kwargs = self.model.default_args.copy()
        self.classify_kwargs["P_threshold"] = self.threshold_p
        self.classify_kwargs["S_threshold"] = self.threshold_s
        self.classify_kwargs["blinding"] = self.blinding
